@@ -1,3 +1,19 @@
+/*
+ * Copyright 2002,2004 The Apache Software Foundation.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
 #ifndef __PERLCALLBACKHANDLER
 #define __PERLCALLBACKHANDLER
 
@@ -40,6 +56,12 @@ extern "C" {
 #define PERLCALLBACKHANDLER_CONTENT_TYPE       3
 #define PERLCALLBACKHANDLER_DOCUMENT_TYPE      4
 
+#include "xercesc/util/TransService.hpp"
+#include "xercesc/util/XMLString.hpp"
+#include "xercesc/util/PlatformUtils.hpp"
+
+XERCES_CPP_NAMESPACE_USE
+
 class PerlCallbackHandler {
 
 private:
@@ -58,6 +80,7 @@ public:
     virtual int type() {return PERLCALLBACKHANDLER_BASE_TYPE;}
 
     SV* set_callback_obj(SV*);
+    SV* XMLString2Perl(const XMLCh*);
 };
 
 #endif /* __PERLCALLBACKHANDLER */
