@@ -1,3 +1,19 @@
+/*
+ * Copyright 2002,2004 The Apache Software Foundation.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
 #include <stdlib.h>
 #include "PerlDocumentCallbackHandler.hpp"
 
@@ -48,9 +64,7 @@ PerlDocumentCallbackHandler::startElement(const XMLCh* const name,
     XPUSHs(callbackObj);
 
         // the next argument is the element name
-    char *cptr = XMLString::transcode(name);
-    SV *string = sv_newmortal();
-    sv_setpv(string, (char *)cptr);
+    SV *string = XMLString2Perl(name);
     XPUSHs(string);
 
         // next is the attribute list
@@ -63,9 +77,6 @@ PerlDocumentCallbackHandler::startElement(const XMLCh* const name,
 
     perl_call_method("start_element", G_DISCARD);
 
-	// transcode mallocs this and leaves it up to us to free the memory
-    delete [] cptr;
-
     FREETMPS;
     LEAVE;
 }
@@ -85,18 +96,13 @@ PerlDocumentCallbackHandler::endElement(const XMLCh* const name)
     XPUSHs(callbackObj);
 
         // the next argument is the element name
-    char *cptr = XMLString::transcode(name);
-    SV *string = sv_newmortal();
-    sv_setpv(string, (char *)cptr);
+    SV *string = XMLString2Perl(name);
     XPUSHs(string);
 
     PUTBACK;
 
     perl_call_method("end_element", G_DISCARD);
 
-	// transcode mallocs this and leaves it up to us to free the memory
-    delete [] cptr;
-
     FREETMPS;
     LEAVE;
 }
@@ -116,10 +122,8 @@ PerlDocumentCallbackHandler::characters(const XMLCh* const chars,
 	// first put the callback object on the stack
     XPUSHs(callbackObj);
 
-        // the next argument is the element name
-    char *cptr = XMLString::transcode(chars);
-    SV *string = sv_newmortal();
-    sv_setpv(string, (char *)cptr);
+        // the next argument is the char data
+    SV *string = XMLString2Perl(chars);
     XPUSHs(string);
 
         // next is the length
@@ -129,9 +133,6 @@ PerlDocumentCallbackHandler::characters(const XMLCh* const chars,
 
     perl_call_method("characters", G_DISCARD);
 
-	// transcode mallocs this and leaves it up to us to free the memory
-    delete [] cptr;
-
     FREETMPS;
     LEAVE;
 }
@@ -151,9 +152,7 @@ PerlDocumentCallbackHandler::ignorableWhitespace(const XMLCh* const chars,
     XPUSHs(callbackObj);
 
         // the next argument is the element name
-    char *cptr = XMLString::transcode(chars);
-    SV *string = sv_newmortal();
-    sv_setpv(string, (char *)cptr);
+    SV *string = XMLString2Perl(chars);
     XPUSHs(string);
 
         // next is the length
@@ -163,9 +162,6 @@ PerlDocumentCallbackHandler::ignorableWhitespace(const XMLCh* const chars,
 
     perl_call_method("ignorable_whitespace", G_DISCARD);
 
-	// transcode mallocs this and leaves it up to us to free the memory
-    delete [] cptr;
-
     FREETMPS;
     LEAVE;
 }
@@ -254,25 +250,17 @@ PerlDocumentCallbackHandler::processingInstruction(const XMLCh* const target,
     XPUSHs(callbackObj);
 
         // the next argument is the target
-    char *cptr1 = XMLString::transcode(target);
-    SV *string1 = sv_newmortal();
-    sv_setpv(string1, (char *)cptr1);
+    SV *string1 = XMLString2Perl(target);
     XPUSHs(string1);
 
         // the next argument is the data
-    char *cptr2 = XMLString::transcode(data);
-    SV *string2 = sv_newmortal();
-    sv_setpv(string2, (char *)cptr2);
+    SV *string2 = XMLString2Perl(data);
     XPUSHs(string2);
 
     PUTBACK;
 
     perl_call_method("processing_instruction", G_DISCARD);
 
-	// transcode mallocs this and leaves it up to us to free the memory
-    delete [] cptr1;
-    delete [] cptr2;
-
     FREETMPS;
     LEAVE;
 }
