@@ -9,4 +9,8 @@ if ($Config{gccversion}) {
 
   # gcc on solaris needs HAS_BOOL
   $self->{CCFLAGS} .= " -DHAS_BOOL";
+} else {
+  # Workshop 6 CC needs C++ runtime library linked
+  $self->{LIBS}->[0] .= " -lCrun";
 }
+
