@@ -1,70 +1,31 @@
+ #
+ #  Copyright 2002,2004 The Apache Software Foundation.
+ #
+ #  Licensed under the Apache License, Version 2.0 (the "License");
+ #  you may not use this file except in compliance with the License.
+ #  You may obtain a copy of the License at
+ #
+ #       http://www.apache.org/licenses/LICENSE-2.0
+ #
+ #  Unless required by applicable law or agreed to in writing, software
+ #  distributed under the License is distributed on an "AS IS" BASIS,
+ #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ #  See the License for the specific language governing permissions and
+ #  limitations under the License.
+ #
+
 ######################################################################
 #
-# The Apache Software License, Version 1.1
-# 
-# Copyright (c) 1999-2000 The Apache Software Foundation.  All rights 
-# reserved.
-# 
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions
-# are met:
-# 
-# 1. Redistributions of source code must retain the above copyright
-#    notice, this list of conditions and the following disclaimer. 
-# 
-# 2. Redistributions in binary form must reproduce the above copyright
-#    notice, this list of conditions and the following disclaimer in
-#    the documentation and/or other materials provided with the
-#    distribution.
-# 
-# 3. The end-user documentation included with the redistribution,
-#    if any, must include the following acknowledgment:  
-#       "This product includes software developed by the
-#        Apache Software Foundation (http://www.apache.org/)."
-#    Alternately, this acknowledgment may appear in the software itself,
-#    if and wherever such third-party acknowledgments normally appear.
-# 
-# 4. The names "Xerces" and "Apache Software Foundation" must
-#    not be used to endorse or promote products derived from this
-#    software without prior written permission. For written 
-#    permission, please contact apache\@apache.org.
-# 
-# 5. Products derived from this software may not be called "Apache",
-#    nor may "Apache" appear in their name, without prior written
-#    permission of the Apache Software Foundation.
-# 
-# THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
-# WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
-# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-# DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
-# ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
-# USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
-# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-# SUCH DAMAGE.
-# ====================================================================
-# 
-# This software consists of voluntary contributions made by many
-# individuals on behalf of the Apache Software Foundation, and was
-# originally based on software copyright (c) 1999, International
-# Business Machines, Inc., http://www.ibm.com .  For more information
-# on the Apache Software Foundation, please see
-# <http://www.apache.org/>.
+# SEnumVal
 #
-######################################################################
-#
-# EnumVal
-#
-# This sample is modeled after its XML4C counterpart.  You give it an
-# XML file and it parses it and enumerates the DTD Grammar. It shows 
-# how to access the DTD information stored in the internal data structurs
+# This sample is modeled after its Xerces-C counterpart.  You give it an
+# XML file and it parses it and enumerates the Schema Grammar. It shows
+# how to access the Schema information stored in the internal data structurs
 #
 ######################################################################
 
 use strict;
+use blib;
 use XML::Xerces qw(error);
 use Getopt::Long;
 use Benchmark;
@@ -88,8 +49,15 @@ die $USAGE unless scalar @ARGV;
 my $file = $ARGV[0];
 -f $file or die "File '$file' does not exist!\n";
 
+  # NOTICE: We must now explicitly call XMLPlatformUtils::Initialize()
+  #   when the module is loaded. Xerces.pm no longer does this.
+  #
+  #
+XML::Xerces::XMLPlatformUtils::Initialize();
+
 my $val_to_use = XML::Xerces::SchemaValidator->new();
 my $parser = XML::Xerces::SAXParser->new($val_to_use);
+
 $parser->setValidationScheme ($XML::Xerces::AbstractDOMParser::Val_Auto);
 $parser->setErrorHandler(XML::Xerces::PerlErrorHandler->new());
 $parser->setDoNamespaces(1);
@@ -157,3 +125,11 @@ my $td = timediff($t1, $t0);
 
 print STDOUT "$file: duration: ", timestr($td), "\n";
 exit(0);
+
+END {
+  # NOTICE: We must now explicitly call XMLPlatformUtils::Terminate()
+  #   when the module is unloaded. Xerces.pm no longer does this for us
+  #
+  #
+  XML::Xerces::XMLPlatformUtils::Terminate();
+}
